"""
    Allow for_runners to be executable
    through `python -m for_runners`.
"""
from pathlib import Path

from manage_django_project.config import ManageConfig
from manage_django_project.manage import execute_django_from_command_line

import for_runners
import for_runners_project


def main():
    """
    entrypoint installed via pyproject.toml and [project.scripts] section.
    Must be set in ./manage.py and PROJECT_SHELL_SCRIPT
    """
    execute_django_from_command_line(
        config=ManageConfig(
            module=for_runners_project,
            project_root_path=Path(for_runners.__file__).parent.parent,
            local_settings='for_runners_project.settings.local',
            test_settings='for_runners_project.settings.tests',
        )
    )


if __name__ == '__main__':
    main()



from django.core.checks import Warning, register
from django.db import OperationalError

from for_runners.models import DistanceModel


@register()
def distance_model_filled(app_configs, **kwargs):
    errors = []

    try:
        distance_model_count = DistanceModel.objects.all().count()
    except OperationalError:
        # e.g.: migration not done, yet
        pass
    else:
        if distance_model_count == 0:
            errors.append(
                Warning(
                    'Distance model is empty!',
                    hint='Just call "./manage.py fill_basedata" manage command',
                    id='for_runners.W001',
                )
            )
    return errors
